==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QTechnique.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Encapsulates a Technique</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html">Qt3DRender::QTechnique</a></code></p>
 */
public class QTechnique extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTechnique.class);
    
    
    /**
     * <p>See <code>Qt3DRender::QTechnique::<wbr>QTechnique(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QTechnique(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTechnique instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addFilterKey">Qt3DRender::QTechnique::<wbr>addFilterKey(Qt3DRender::QFilterKey*)</a></code></p>
     */
    @QtUninvokable
    public final void addFilterKey(io.qt.qt3d.render.@Nullable QFilterKey filterKey){
        addFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @QtUninvokable
    private native void addFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addParameter">Qt3DRender::QTechnique::<wbr>addParameter(Qt3DRender::QParameter*)</a></code></p>
     */
    @QtUninvokable
    public final void addParameter(io.qt.qt3d.render.@Nullable QParameter p){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addRenderPass">Qt3DRender::QTechnique::<wbr>addRenderPass(Qt3DRender::QRenderPass*)</a></code></p>
     */
    @QtUninvokable
    public final void addRenderPass(io.qt.qt3d.render.@Nullable QRenderPass pass){
        addRenderPass_native_Qt3DRender_QRenderPass_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(pass));
    }
    
    @QtUninvokable
    private native void addRenderPass_native_Qt3DRender_QRenderPass_ptr(long __this__nativeId, long pass);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#filterKeys">Qt3DRender::QTechnique::<wbr>filterKeys()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QFilterKey> filterKeys(){
        return filterKeys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QFilterKey> filterKeys_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#parameters">Qt3DRender::QTechnique::<wbr>parameters()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeFilterKey">Qt3DRender::QTechnique::<wbr>removeFilterKey(Qt3DRender::QFilterKey*)</a></code></p>
     */
    @QtUninvokable
    public final void removeFilterKey(io.qt.qt3d.render.@Nullable QFilterKey filterKey){
        removeFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @QtUninvokable
    private native void removeFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeParameter">Qt3DRender::QTechnique::<wbr>removeParameter(Qt3DRender::QParameter*)</a></code></p>
     */
    @QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.@Nullable QParameter p){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeRenderPass">Qt3DRender::QTechnique::<wbr>removeRenderPass(Qt3DRender::QRenderPass*)</a></code></p>
     */
    @QtUninvokable
    public final void removeRenderPass(io.qt.qt3d.render.@Nullable QRenderPass pass){
        removeRenderPass_native_Qt3DRender_QRenderPass_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(pass));
    }
    
    @QtUninvokable
    private native void removeRenderPass_native_Qt3DRender_QRenderPass_ptr(long __this__nativeId, long pass);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#renderPasses">Qt3DRender::QTechnique::<wbr>renderPasses()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QRenderPass> renderPasses(){
        return renderPasses_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QRenderPass> renderPasses_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTechnique(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTechnique(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTechnique instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTechnique(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTechnique() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.6.3-sources.jar: io/qt/qt3d/render/QTechnique.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Encapsulates a Technique</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html">Qt3DRender::QTechnique</a></code></p>
 */
public class QTechnique extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTechnique.class);
    
    
    /**
     * <p>See <code>Qt3DRender::QTechnique::<wbr/>QTechnique(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QTechnique(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTechnique instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addFilterKey">Qt3DRender::QTechnique::<wbr/>addFilterKey(Qt3DRender::QFilterKey*)</a></code></p>
     */
    @QtUninvokable
    public final void addFilterKey(io.qt.qt3d.render.@Nullable QFilterKey filterKey){
        addFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @QtUninvokable
    private native void addFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addParameter">Qt3DRender::QTechnique::<wbr/>addParameter(Qt3DRender::QParameter*)</a></code></p>
     */
    @QtUninvokable
    public final void addParameter(io.qt.qt3d.render.@Nullable QParameter p){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addRenderPass">Qt3DRender::QTechnique::<wbr/>addRenderPass(Qt3DRender::QRenderPass*)</a></code></p>
     */
    @QtUninvokable
    public final void addRenderPass(io.qt.qt3d.render.@Nullable QRenderPass pass){
        addRenderPass_native_Qt3DRender_QRenderPass_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(pass));
    }
    
    @QtUninvokable
    private native void addRenderPass_native_Qt3DRender_QRenderPass_ptr(long __this__nativeId, long pass);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#filterKeys">Qt3DRender::QTechnique::<wbr/>filterKeys()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QFilterKey> filterKeys(){
        return filterKeys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QFilterKey> filterKeys_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#parameters">Qt3DRender::QTechnique::<wbr/>parameters()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeFilterKey">Qt3DRender::QTechnique::<wbr/>removeFilterKey(Qt3DRender::QFilterKey*)</a></code></p>
     */
    @QtUninvokable
    public final void removeFilterKey(io.qt.qt3d.render.@Nullable QFilterKey filterKey){
        removeFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @QtUninvokable
    private native void removeFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeParameter">Qt3DRender::QTechnique::<wbr/>removeParameter(Qt3DRender::QParameter*)</a></code></p>
     */
    @QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.@Nullable QParameter p){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeRenderPass">Qt3DRender::QTechnique::<wbr/>removeRenderPass(Qt3DRender::QRenderPass*)</a></code></p>
     */
    @QtUninvokable
    public final void removeRenderPass(io.qt.qt3d.render.@Nullable QRenderPass pass){
        removeRenderPass_native_Qt3DRender_QRenderPass_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(pass));
    }
    
    @QtUninvokable
    private native void removeRenderPass_native_Qt3DRender_QRenderPass_ptr(long __this__nativeId, long pass);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#renderPasses">Qt3DRender::QTechnique::<wbr/>renderPasses()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QRenderPass> renderPasses(){
        return renderPasses_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QRenderPass> renderPasses_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTechnique(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QTechnique(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTechnique instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTechnique(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTechnique() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
